You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@logging.apache.org by ts...@apache.org on 2017/10/16 09:26:08 UTC

[2/2] logging-log4cxx git commit: LOGCXX-493: LoggingEvent::timeStamp and ::getStartTime were documented to provide milliseconds, but are ultimately set using apr_time_now and that provides microseconds. Additionally, RelativeTimeDateFormat was documente

LOGCXX-493: LoggingEvent::timeStamp and ::getStartTime were documented to provide milliseconds, but are ultimately set using apr_time_now and that provides microseconds. Additionally, RelativeTimeDateFormat was documented to provide seconds, but is based on getStartTime with microseconds and ttcclayout.h documents that RelativeTimeDateFormat provides milliseconds as well. So implementation of RelativeTimeDateFormat is the same like for RelativeTimePatternConverter, which documents to provide milliseconds, too.


Project: http://git-wip-us.apache.org/repos/asf/logging-log4cxx/repo
Commit: http://git-wip-us.apache.org/repos/asf/logging-log4cxx/commit/4cf6ae6f
Tree: http://git-wip-us.apache.org/repos/asf/logging-log4cxx/tree/4cf6ae6f
Diff: http://git-wip-us.apache.org/repos/asf/logging-log4cxx/diff/4cf6ae6f

Branch: refs/heads/master
Commit: 4cf6ae6f16a307f242216b1c669c2d9213b82712
Parents: ff1a5ed
Author: Thorsten Schöning <ts...@am-soft.de>
Authored: Mon Oct 16 11:26:04 2017 +0200
Committer: Thorsten Schöning <ts...@am-soft.de>
Committed: Mon Oct 16 11:26:04 2017 +0200

----------------------------------------------------------------------
 src/changes/changes.xml                                   | 1 +
 src/main/include/log4cxx/helpers/relativetimedateformat.h | 2 +-
 src/main/include/log4cxx/spi/loggingevent.h               | 4 ++--
 3 files changed, 4 insertions(+), 3 deletions(-)
----------------------------------------------------------------------


http://git-wip-us.apache.org/repos/asf/logging-log4cxx/blob/4cf6ae6f/src/changes/changes.xml
----------------------------------------------------------------------
diff --git a/src/changes/changes.xml b/src/changes/changes.xml
index 2be88c0..fbec857 100644
--- a/src/changes/changes.xml
+++ b/src/changes/changes.xml
@@ -26,6 +26,7 @@
 		<release	version="0.11.0"
 					date="XXXX-XX-XX"
 					description="Maintenance release">
+			<action issue="LOGCXX-493" type="fix">Wrong usage of milli- vs. micro- and non- vs. milliseconds in some docs.</action>
 			<action issue="LOGCXX-488" type="fix">Space after log level hides messages</action>
 			<action issue="LOGCXX-484" type="fix">Spelling error s/excute/execute</action>
 			<action issue="LOGCXX-482" type="fix">Build failure with GCC-6</action>

http://git-wip-us.apache.org/repos/asf/logging-log4cxx/blob/4cf6ae6f/src/main/include/log4cxx/helpers/relativetimedateformat.h
----------------------------------------------------------------------
diff --git a/src/main/include/log4cxx/helpers/relativetimedateformat.h b/src/main/include/log4cxx/helpers/relativetimedateformat.h
index b60d62f..85daade 100644
--- a/src/main/include/log4cxx/helpers/relativetimedateformat.h
+++ b/src/main/include/log4cxx/helpers/relativetimedateformat.h
@@ -25,7 +25,7 @@ namespace log4cxx
         namespace helpers
         {
                 /**
-                Formats a date by printing the number of seconds
+                Formats a date by printing the number of milliseconds
                 elapsed since the start of the application. This is the fastest
                 printing DateFormat in the package.
                 */

http://git-wip-us.apache.org/repos/asf/logging-log4cxx/blob/4cf6ae6f/src/main/include/log4cxx/spi/loggingevent.h
----------------------------------------------------------------------
diff --git a/src/main/include/log4cxx/spi/loggingevent.h b/src/main/include/log4cxx/spi/loggingevent.h
index c78e891..f2b2a55 100644
--- a/src/main/include/log4cxx/spi/loggingevent.h
+++ b/src/main/include/log4cxx/spi/loggingevent.h
@@ -103,7 +103,7 @@ namespace log4cxx
                                 { return message; }
 
                         /**Returns the time when the application started,
-                        in seconds elapsed since 01.01.1970.
+                        in microseconds elapsed since 01.01.1970.
                         */
                         static log4cxx_time_t getStartTime();
 
@@ -228,7 +228,7 @@ namespace log4cxx
                         LogString message;
 
 
                         /** The number of milliseconds elapsed from 1/1/1970 until logging event
                          was created. */
                         log4cxx_time_t timeStamp;
@@ -228,7 +228,7 @@ namespace log4cxx
 
 
-                        /** The number of milliseconds elapsed from 1/1/1970 until logging event
+                        /** The number of microseconds elapsed from 01.01.1970 until logging event
                          was created. */
                         log4cxx_time_t timeStamp;